@@ -37,9 +37,8 @@
 #else
 #include <Akonadi/Calendar/History>
 #endif
-#include <CalendarSupport/KCalPrefs>
-#include <CalendarSupport/Utils>
-#include <EventViews/Prefs>
+
+
 #include <KCheckableProxyModel>
 #include <KDescendantsProxyModel>
 #include <KLocalizedString>
@@ -47,7 +46,7 @@
 #include <QDebug>
 #include <QPointer>
 #include <QRandomGenerator>
-#include <models/todosortfilterproxymodel.h>
+// #include <models/todosortfilterproxymodel.h>
 
 #if AKONADICALENDAR_VERSION > QT_VERSION_CHECK(5, 19, 41)
 #include <Akonadi/ETMCalendar>
@@ -74,11 +73,6 @@ static Akonadi::EntityTreeModel *findEtm(QAbstractItemModel *model)
     return qobject_cast<Akonadi::EntityTreeModel *>(model);
 }
 
-bool isStandardCalendar(Akonadi::Collection::Id id)
-{
-    return id == CalendarSupport::KCalPrefs::instance()->defaultCalendarId();
-}
-
 /**
  * Automatically checks new calendar entries
  */
@@ -146,19 +140,7 @@ protected:
         return true;
     }
 
-    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override
-    {
-        if (role == Qt::ToolTipRole) {
-#if AKONADI_VERSION < QT_VERSION_CHECK(5, 20, 41)
-            const Akonadi::Collection col = CalendarSupport::collectionFromIndex(index);
-#else
-            const Akonadi::Collection col = Akonadi::CollectionUtils::fromIndex(index);
-#endif
-            return CalendarSupport::toolTipString(col);
-        }
-
-        return QSortFilterProxyModel::data(index, role);
-    };
+    
 };
 
 class KalendarCollectionFilterProxyModel : public Akonadi::CollectionFilterProxyModel
@@ -205,6 +187,7 @@ CalendarManager::CalendarManager(QObject *parent)
     auto colorProxy = new ColorProxyModel(this);
     colorProxy->setObjectName(QStringLiteral("Show calendar colors"));
     colorProxy->setDynamicSortFilter(true);
+  
     m_baseModel = colorProxy;
 
     // Hide collections that are not required
@@ -237,10 +220,10 @@ CalendarManager::CalendarManager(QObject *parent)
     m_eventMimeTypeFilterModel->addMimeTypeFilter(QStringLiteral("application/x-vnd.akonadi.calendar.event"));
 
     // text/calendar mimetype includes todo cals
-    m_todoMimeTypeFilterModel = new Akonadi::CollectionFilterProxyModel(this);
-    m_todoMimeTypeFilterModel->setSourceModel(collectionFilter);
-    m_todoMimeTypeFilterModel->addMimeTypeFilter(QStringLiteral("application/x-vnd.akonadi.calendar.todo"));
-    m_todoMimeTypeFilterModel->setExcludeVirtualCollections(true);
+    // m_todoMimeTypeFilterModel = new Akonadi::CollectionFilterProxyModel(this);
+    // m_todoMimeTypeFilterModel->setSourceModel(collectionFilter);
+    // m_todoMimeTypeFilterModel->addMimeTypeFilter(QStringLiteral("application/x-vnd.akonadi.calendar.todo"));
+    // m_todoMimeTypeFilterModel->setExcludeVirtualCollections(true);
 
     // Filter by access rights
     m_allCollectionsRightsFilterModel = new Akonadi::EntityRightsFilterModel(this);
@@ -251,9 +234,9 @@ CalendarManager::CalendarManager(QObject *parent)
     m_eventRightsFilterModel->setAccessRights(Collection::CanCreateItem);
     m_eventRightsFilterModel->setSourceModel(m_eventMimeTypeFilterModel);
 
-    m_todoRightsFilterModel = new Akonadi::EntityRightsFilterModel(this);
-    m_todoRightsFilterModel->setAccessRights(Collection::CanCreateItem);
-    m_todoRightsFilterModel->setSourceModel(m_todoMimeTypeFilterModel);
+    // m_todoRightsFilterModel = new Akonadi::EntityRightsFilterModel(this);
+    // m_todoRightsFilterModel->setAccessRights(Collection::CanCreateItem);
+    // m_todoRightsFilterModel->setSourceModel(m_todoMimeTypeFilterModel);
 
     // Use our custom class to order them properly
     m_selectableCollectionsModel = new KalendarCollectionFilterProxyModel(this);
@@ -431,7 +414,7 @@ qint64 CalendarManager::defaultCalendarId(IncidenceWrapper *incidenceWrapper)
 {
     // Checks if default collection accepts this type of incidence
     auto mimeType = incidenceWrapper->incidencePtr()->mimeType();
-    Akonadi::Collection collection = m_calendar->collection(CalendarSupport::KCalPrefs::instance()->defaultCalendarId());
+    Akonadi::Collection collection = m_calendar->collection(-1);
     bool supportsMimeType = collection.contentMimeTypes().contains(mimeType) || mimeType == QLatin1String("");
     bool hasRights = collection.rights() & Akonadi::Collection::CanCreateItem;
     if (collection.isValid() && supportsMimeType && hasRights) {
@@ -759,8 +742,7 @@ QVariantMap CalendarManager::getCollectionDetails(QVariant collectionId)
     collectionDetails[QLatin1String("id")] = collection.id();
     collectionDetails[QLatin1String("name")] = collection.name();
     collectionDetails[QLatin1String("displayName")] = collection.displayName();
-    collectionDetails[QLatin1String("color")] = m_baseModel->colorCache[QString::number(collection.id())];
-    collectionDetails[QLatin1String("count")] = collection.statistics().count();
+    collectionDetails[QLatin1String("color")] = m_baseModel->color(collection.id());    collectionDetails[QLatin1String("count")] = collection.statistics().count();
     collectionDetails[QLatin1String("isResource")] = Akonadi::CollectionUtils::isResource(collection);
     collectionDetails[QLatin1String("resource")] = collection.resource();
     collectionDetails[QLatin1String("readOnly")] = collection.rights().testFlag(Collection::ReadOnly);
@@ -784,8 +766,7 @@ void CalendarManager::setCollectionColor(qint64 collectionId, const QColor &colo
         if (job->error()) {
             qWarning() << "Error occurred modifying collection color: " << job->errorString();
         } else {
-            m_baseModel->colorCache[QString::number(collectionId)] = color;
-            m_baseModel->save();
+             m_baseModel->setColor(collectionId, color);
         }
     });
 }
